==> tw-api-common-2.2.18-20230629.005748-1-sources.jar: com/elitesland/tw/tw5/api/prd/app/vo/PrdUserDataForAppVO.java <==
package com.elitesland.tw.tw5.api.prd.app.vo;

import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.math.BigDecimal;

@Data
public class PrdUserDataForAppVO {

    @ApiModelProperty("记录唯一ID")
    @JsonSerialize(using = ToStringSerializer.class)
    private Long id;
    /**
     * 员工姓名
     */
    private String employeeName;
//    /**
//     * 公司ID
//     */
//    private Long companyId;
//    /**
//     * 公司名称
//     */
//    private String companyName;
//    /**
//     * 员工编号
//     */
//    private String employeeNo;
    /**
     * 用户邮箱
     */
    private String email;
    /**
     * 手机号
     */
    private String mobile;
//    /**
//     * ticket
//     */
//    private String pcLoginTicket;
    /**
     * 组织ID
     */
    private Long orgId;
    /**
     * 组织名称
     */
    private String orgName;
    /**
     * 岗位
     */
    private String jobs;
    /**
     * 岗位名称
     */
    private String jobsName;

    /**
     * 性别
     */
    private String sex;
    /**
     * 性别
     */
    private String sexName;
    /**
     * 组织角色
     */
//    private List<String> orgRoles;
//    /**
//     * 我的快捷入口ids
//     */
//    private String shortcutIds = "";
//    /**
//     * 快捷入口数据
//     */
//    private List<PrdSystemShortcutVO> shortcutVOs;

    /**
     * 头像url
     */
    private String headCodes;
//    private Object headDatas;

    /**
     * ticekt
     */
//    private String ticket;

    /**
     * 当量系数
     */
    private BigDecimal eqvaRatio = BigDecimal.ZERO;

    /**
     * 是否 启用工作流
     */
    private Boolean workflowEnabled;

}

==> tw-api-common-2.4.3.8-20230817.024025-1-sources.jar: com/elitesland/tw/tw5/api/prd/app/vo/PrdUserDataForAppVO.java <==
package com.elitesland.tw.tw5.api.prd.app.vo;

import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.math.BigDecimal;
import java.util.List;

@Data
public class PrdUserDataForAppVO {

    @ApiModelProperty("记录唯一ID")
    @JsonSerialize(using = ToStringSerializer.class)
    private Long id;

    @JsonSerialize(using = ToStringSerializer.class)
    private Long userId;
    /**
     * 员工姓名
     */
    private String employeeName;
//    /**
//     * 公司ID
//     */
//    private Long companyId;
//    /**
//     * 公司名称
//     */
//    private String companyName;
//    /**
//     * 员工编号
//     */
//    private String employeeNo;
    /**
     * 用户邮箱
     */
    private String email;
    /**
     * 手机号
     */
    private String mobile;
//    /**
//     * ticket
//     */
//    private String pcLoginTicket;
    /**
     * 组织ID
     */
    private Long orgId;
    /**
     * 组织名称
     */
    private String orgName;
    /**
     * 岗位
     */
    private String jobs;
    /**
     * 岗位名称
     */
    private String jobsName;

    /**
     * 性别
     */
    private String sex;
    /**
     * 性别
     */
    private String sexName;
    /**
     * 组织角色
     */
    private List<String> orgRoles;
    /**
     * 系统角色编码
     */
    private List<String> systemRoles;
//    /**
//     * 我的快捷入口ids
//     */
//    private String shortcutIds = "";
//    /**
//     * 快捷入口数据
//     */
//    private List<PrdSystemShortcutVO> shortcutVOs;

    /**
     * 头像url
     */
    private String headCodes;
//    private Object headDatas;

    /**
     * ticekt
     */
//    private String ticket;

    /**
     * 当量系数
     */
    private BigDecimal eqvaRatio = BigDecimal.ZERO;

    /**
     * 是否 启用工作流
     */
    private Boolean workflowEnabled;

}
